@@ -347,7 +347,6 @@ void Kile::setupBottomBar()
 	m_bottomBar->addTab(m_texKonsole, SmallIcon("konsole"),i18n("Konsole"));
 	connect(viewManager()->tabs(), SIGNAL( currentChanged( QWidget * ) ), m_texKonsole, SLOT(sync()));
 
-	m_bottomBar->showPage(m_logWidget);
 	m_bottomBar->setVisible(true);
 	m_bottomBar->setSize(KileConfig::bottomBarSize());
 }
@@ -1033,7 +1032,8 @@ void Kile::findInProjects()
 /////////////////// PART & EDITOR WIDGET //////////
 void Kile::showEditorWidget()
 {
-	resetPart();
+	if(!resetPart())
+		return;
 	setCentralWidget(m_topWidgetStack);
 	m_topWidgetStack->show();
 	m_horizontalSplitter->show();
@@ -1048,7 +1048,7 @@ void Kile::showEditorWidget()
 }
 
 
-void Kile::resetPart()
+bool Kile::resetPart()
 {
 	kdDebug() << "==Kile::resetPart()=============================" << endl;
 	kdDebug() << "\tcurrent state " << m_currentState << endl;
@@ -1058,10 +1058,14 @@ void Kile::resetPart()
 
 	if (part && m_currentState != "Editor")
 	{
-		part->closeURL();
-		m_partManager->removePart(part) ;
-		m_topWidgetStack->removeWidget(part->widget());
-		delete part;
+		if(part->closeURL())
+		{
+			m_partManager->removePart(part);
+			m_topWidgetStack->removeWidget(part->widget());
+			delete part;
+		}
+		else
+			return false;
 	}
 
     setupStatusBar();
@@ -1071,6 +1075,7 @@ void Kile::resetPart()
 	m_currentState = "Editor";
 	m_wantState = "Editor";
 	m_partManager->setActivePart( 0L);
+	return true;
 }
 
 void Kile::activePartGUI(KParts::Part * part)
@@ -1807,8 +1812,10 @@ void Kile::saveSettings()
 	KileConfig::setBottomBar(m_bottomBar->isVisible());
 	KileConfig::setBottomBarSize(sizeBottomBar);
 
-	KileConfig::setSelectedLeftView(m_sideBar->currentTab());
-
+	if(m_sideBar->isVisible())
+		KileConfig::setSelectedLeftView(m_sideBar->currentTab());
+	else
+		KileConfig::setSelectedLeftView(-1);
 	KileConfig::writeConfig();
 	m_config->sync();
 }
