@@ -33,6 +33,7 @@
 #include <kstandarddirs.h>
 #include <kio/netaccess.h>
 #include <kpushbutton.h>
+#include <kurl.h>
 
 #include "kileuntitled.h"
 #include "templates.h"
@@ -742,33 +743,43 @@ void Manager::fileSaveAll(bool amAutoSaving, bool disUntitled )
 {
 	Kate::View *view;
 	QFileInfo fi;
-
-	kdDebug() << "==Kile::fileSaveAll=================" << endl;
-	kdDebug() << "\tautosaving = " << amAutoSaving << ",  DisRegardUntitled = " <<  disUntitled << endl;
+	bool successBackup;
+	int saveResult;
+	QString backupFileName;
+	KURL url;
+	
+	kdDebug() << "===Kile::fileSaveAll=================" << endl;
+	kdDebug() << "autosaving = " << amAutoSaving << ", DisUntitled = " << disUntitled << endl;
 
 	for (uint i = 0; i < m_ki->viewManager()->views().count(); ++i)
 	{
 		view = m_ki->viewManager()->view(i);
 
-		if (view && (view->getDoc()->isModified() || amAutoSaving) )
+		if ( view && (view->getDoc()->isModified() || amAutoSaving) )
 		{
-			fi.setFile(view->getDoc()->url().path());
-
-			if ( (!amAutoSaving && !disUntitled)	// both false, so we want to save everything
-				 || ( !amAutoSaving && !(disUntitled && view->getDoc()->url().isEmpty() ) ) // DisregardUntitled is true and we have an untitled doc and don't autosave
-			     || ( amAutoSaving && (!view->getDoc()->url().isEmpty() ) && fi.isWritable() ) //don't save unwritable and untitled documents when autosaving
-			   )
+			url = view->getDoc()->url();
+			fi.setFile(url.path());
+			backupFileName = url.path()+ ".backup";
+			
+			if	( 	( !amAutoSaving && !(disUntitled && url.isEmpty() ) ) // DisregardUntitled is true and we have an untitled doc and don't autosave
+					|| ( amAutoSaving && !url.isEmpty() ) //don't save untitled documents when autosaving
+					|| ( !amAutoSaving && !disUntitled )	// both false, so we want to save everything
+				)
 			{
-				kdDebug() << "\tsaving: " << view->getDoc()->url().path() << endl;
-
-				if (amAutoSaving)
+				if (amAutoSaving && fi.size() > 0) // the size check ensures that we don't save empty files (to prevent something like #125809 in the future).
 				{
-					//make a backup
-					KURL url = view->getDoc()->url();
-          KIO::NetAccess::file_copy (url, KURL(KURL::fromPathOrURL(url.url()+".backup")), -1, true, false, kapp->mainWidget());
+					kdDebug() << "autosaving: " << backupFileName << endl;
+					successBackup = KIO::NetAccess::file_copy(url, KURL::fromPathOrURL(backupFileName), -1, true, false, kapp->mainWidget());
+					if(!successBackup)
+						m_ki->logWidget()->printMsg(KileTool::Error,i18n("The file %1 could not be saved, check the permissions and the free disk space!").arg(backupFileName),i18n("Autosave"));
 				}
-
-				view->save();
+				
+				kdDebug() << "saving: " << url.path() << endl;
+				saveResult = view->save();
+				fi.refresh();
+			
+				if(saveResult == Kate::View::SAVE_ERROR && fi.size() == 0  && !url.isEmpty()) // we probably hit bug #125809, inform the user of the possible consequences
+					m_ki->logWidget()->printMsg(KileTool::Error,i18n("Kile encountered problems while saving the file %1. Do you have enough free disk space left?").arg(url.url()),i18n("Saving"));
 			}
 		}
 	}
@@ -787,13 +798,14 @@ void Manager::fileOpen(const KURL & url, const QString & encoding)
 	Kate::View *view = load(url, encoding);
 	KileProjectItem *item = itemFor(url);
 
-	//URL wasn't open before loading, add it to the project view
-	//FIXME: use signal/slot
-	if ( !isopen && item  == 0L )
-		m_ki->viewManager()->projectView()->add(url);
+	if(!isopen)
+	{
+		if(!item)	//URL wasn't open before loading, add it to the project view
+			m_ki->viewManager()->projectView()->add(url);	//FIXME: use signal/slot
+		else if(view)
+			view->setCursorPosition(item->lineNumber(),item->columnNumber());
+	}
 
-	if(view && item)
-		view->setCursorPosition(item->lineNumber(), item->columnNumber());
 	emit(updateStructure(false, 0L));
 	emit(updateModeStatus());
 	// update undefined references in this file
@@ -892,7 +904,7 @@ bool Manager::fileClose(Kate::Document *doc /* = 0L*/, bool closingproject /*= f
 			//FIXME:remove entry in projectview
 			m_ki->viewManager()->removeFromProjectView(url);
 
-            if ( m_ki->docManager()->documentInfos()->count() == 0 ) emit updateModeStatus();
+            emit updateModeStatus();
 		}
 		else
 			return false;
@@ -1166,7 +1178,7 @@ void Manager::updateProjectReferences(KileProject *project)
 KileProject* Manager::projectOpen()
 {
 	kdDebug() << "==Kile::projectOpen==========================" << endl;
-	KURL url = KFileDialog::getOpenURL( "", i18n("*.kilepr|Kile Project Files\n*|All Files"), m_ki->parentWidget(), i18n("Open Project") );
+	KURL url = KFileDialog::getOpenURL( KileConfig::defaultProjectLocation(), i18n("*.kilepr|Kile Project Files\n*|All Files"), m_ki->parentWidget(), i18n("Open Project") );
 
 	if (!url.isEmpty())
 		return projectOpen(url);
