@@ -173,6 +173,7 @@ void EditorExtension::insertTag(const KileAction::TagData& data, Kate::View *vie
 	//do some replacements
 	QFileInfo fi( doc->url().path());
 	ins.replace("%S", fi.baseName(true));
+	ins.replace("%B", s_bullet);
 	
 	//insert first part of tag at cursor position
 	doc->insertText(para,index,ins);
@@ -1541,8 +1542,8 @@ bool EditorExtension::insertDoubleQuotes()
 	view->cursorPositionReal(&row,&col);
 	Kate::Document *doc = view->getDoc();
 	
-	// simply insert, if autoinsert mode is not active
-	if ( ! m_dblQuotes ) 
+	// simply insert, if autoinsert mode is not active or the char bevor is \ (typically for \"a useful)
+	if ( !m_dblQuotes || ( col > 0 && doc->text(row,col-1,row,col) == QString("\\") ) ) 
 	{
 		doc->insertText(row,col,"\"");
 		return true;
@@ -1679,7 +1680,7 @@ bool EditorExtension::eventInsertEnvironment(Kate::View *view)
 			endenv = m_regexpEnter.cap(2).replace("\\begin","\\end")+"\n";
 		}
 		
-		if ( shouldCompleteEnv(envname, view) ) 
+		if ( shouldCompleteEnv(envname, view) )
 		{
 			QString item =  m_latexCommands->isListEnv(envname) ? "\\item " : QString::null;
 			view->getDoc()->insertText(row,col, '\n'+line+m_envAutoIndent+item +'\n'+line+endenv);
@@ -1692,16 +1693,19 @@ bool EditorExtension::eventInsertEnvironment(Kate::View *view)
 
 bool EditorExtension::shouldCompleteEnv(const QString &env, Kate::View *view)
 {
+	kdDebug() << "===EditorExtension::shouldCompleteEnv(...)===" << endl;
+ 	QString envname = env;
+	envname.replace("*","\\*");
 	QRegExp reTestBegin,reTestEnd;
-	if ( env == "\\[" )
+	if ( envname == "\\[" )
 	{
 		reTestBegin.setPattern("\\\\\\[");
 		reTestEnd.setPattern("\\\\\\]");
 	}
 	else
 	{
-		reTestBegin.setPattern("\\\\begin\\s*\\{" + env + "\\}");
-		reTestEnd.setPattern("\\\\end\\s*\\{" + env + "\\}");
+		reTestBegin.setPattern("\\\\begin\\s*\\{" + envname + "\\}");
+		reTestEnd.setPattern("\\\\end\\s*\\{" + envname + "\\}");
 	}
 	
 	int num = view->getDoc()->numLines();
